@@ -104,11 +104,13 @@ class GeoParquetValidator:
             def retrieve_remote_file(uri: str):
                 if not uri.startswith("http://") and not uri.startswith("https://"):
                     raise Exception(f"Cannot retrieve {uri}")
-                import urllib
+                import urllib.request
 
                 global map_remote_resources
                 if uri not in map_remote_resources:
-                    response = urllib.request.urlopen(uri).read()
+                    response = urllib.request.urlopen(
+                        urllib.request.Request(uri, headers={"User-Agent": "GDAL"})
+                    ).read()
                     map_remote_resources[uri] = response
                 else:
                     response = map_remote_resources[uri]
@@ -178,10 +180,14 @@ class GeoParquetValidator:
             schema_url = f"https://github.com/opengeospatial/geoparquet/releases/download/v{version}/schema.json"
 
             if schema_url not in geoparquet_schemas:
-                import urllib
+                import urllib.request
 
                 try:
-                    response = urllib.request.urlopen(schema_url).read()
+                    response = urllib.request.urlopen(
+                        urllib.request.Request(
+                            schema_url, headers={"User-Agent": "GDAL"}
+                        )
+                    ).read()
                 except Exception as e:
                     return self._error(
                         f"Cannot download GeoParquet JSON schema from {schema_url}. Exception = {repr(e)}"
